@@ -43,13 +43,15 @@ class CompoundingConversationDataset:
     def __init__(
         self,
         path: str = _PATH,
-        end_of_message_token: str = "<EOM>",
+        odd_speaker_token: str = "<speaker1>",
+        even_speaker_token: str = "<speaker2>",
         end_of_utterance_token: str = " ",
         prefix: str = "",
     ) -> None:
         """Instantiate a new ConversationDataset object."""
         self.path = path
-        self.eom_token = end_of_message_token
+        self.odd_speaker_token = odd_speaker_token
+        self.even_speaker_token = even_speaker_token
         self.eou_token = end_of_utterance_token
         self.prefix = prefix
         self._data = json.load(open(self.path))
@@ -58,8 +60,10 @@ class CompoundingConversationDataset:
         """Iterate over input/target tuples."""
         for conv in self._data.values():
             conv = [self.eou_token.join(u["text"] for u in m) for m in conv["messages"]]
-            for m in compound_conversation(conv, self.prefix, self.eom_token):
-                yield m
+            for example in compound_conversation(
+                conv, self.odd_speaker_token, self.even_speaker_token, self.prefix
+            ):
+                yield example
 
 
 class MessageDataset:
@@ -83,18 +87,37 @@ class MessageDataset:
 
 
 def compound_conversation(
-    convo: Iterable[str], prefix: str, eom_token: str
+    convo: Iterable[str],
+    odd_speaker_token: str,
+    even_speaker_token: str,
+    prefix: str = "",
 ) -> Iterator[Tuple[str, str]]:
     """Compounds a single conversation.
 
     Returns an iterator over compounding input/target example tuples of the
-    form (assuming a 4 turn conversation and an `end_of_message_token` of `<TURN>`):
-    ```
-    ("message1", "message2")
-    ("message1<TURN>message2", "message3")
-    ("message1<TURN>message2<TURN>message3", "message4")
-    ```
+    form (assuming a 4 turn conversation)::
+
+        ("<s1>message1", "<s2>message2")
+        ("<s1>message1<s2>message2", "<s1>message3")
+        ("<s1>message1<s2>message2<s1>message3", "<s2>message4")
+
+    Where:
+        * ``<s1>`` denotes the ``odd_speaker_token``
+        * ``<s2>`` denotes the ``even_speaker_token``
     """
+    # NB: switch even and odd tokens because we start at 1
+    even_token = odd_speaker_token
+    odd_token = even_speaker_token
+
     convo = list(convo)
     for i in range(1, len(convo)):
-        yield prefix + eom_token.join(convo[:i]), convo[i]
+        c = "".join(add_alternating_tokens(convo[:i], odd_token, even_token))
+        yield prefix + c, even_token + convo[i] if i % 2 == 0 else odd_token + convo[i]
+
+
+def add_alternating_tokens(
+    convo: Iterable[str], odd_token: str, even_token: str,
+) -> Iterator[str]:
+    """Adds alternating tokens to an iterable (list) of strings."""
+    for i, s in enumerate(convo):
+        yield even_token + s if i % 2 == 0 else odd_token + s
